# lobsters client library

This library can be used to retrieve data from Lobste.rs.

# Example

```python
import lobsters

c = lobsters.Client()

for story in c.frontpage():
    print(story.title)
```

More examples can be found in [examples/](examples/).

# Tests

The tests can be ran by going to the root of the repository and running the
`prove` command.

# Contributing

Before sending a PR, make sure that all the tests are passing. If you have
added or altered any functionality, you should write new tests to cover them
and make sure that the tests reflect the correct behaviour.

Patches can be sent by Pull Requests or via email to `lobsters-py at gkbrk dot
com`.
